@@ -66,6 +66,11 @@ log = logging.getLogger(__name__)
 #      Currently set to 'en' because test_dsd.py expects it.
 DEFAULT_LOCALE = "en"
 
+# Configure validation level (new in v1.8.0)
+# This is currently used only to prevent URN matching
+ValidationLevels = Enum("ValidationLevels", "strict sloppy")
+DEFAULT_VAL_LEVEL = ValidationLevels.sloppy
+
 
 # §3.2: Base structures
 
@@ -158,7 +163,7 @@ class InternationalString:
 
     def localized_default(self, locale=None):
         """Return the string in *locale* if not  empty, or else the first defined."""
-        if locale and (locale in self.localizations) and self.localizations[locale]:  
+        if locale and (locale in self.localizations) and self.localizations[locale]:
             return self.localizations[locale]
         if len(self.localizations):
             # No label in the default locale; use the first stored non-empty str value
@@ -279,7 +284,7 @@ class IdentifiableArtefact(AnnotableArtefact):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        if self.urn:
+        if self.urn and DEFAULT_VAL_LEVEL == ValidationLevels.strict:
             import pandasdmx.urn
 
             self.urn_group = pandasdmx.urn.match(self.urn)
